@@ -2,10 +2,12 @@ from NLP_LIB.nlp_core.model_wrapper import EncoderModelWrapper, TrainableModelWr
 from NLP_LIB.ext.transformer import Transformer
 import random, os, sys
 import numpy as np
-from keras.models import *
-from keras.layers import *
-from keras.callbacks import *
-from keras.initializers import *
+from tensorflow.keras.models import *
+from tensorflow.keras.layers import *
+from tensorflow.keras.callbacks import *
+from tensorflow.keras.initializers import *
+from tensorflow.keras import backend as K
+
 import tensorflow as tf
 
 class TransformerDecoderOnlyWrapper(EncoderModelWrapper, TrainableModelWrapper, SequenceModelWrapper):
