@@ -1,9 +1,11 @@
 from NLP_LIB.nlp_core.model_wrapper import ModelWrapper, SequenceModelWrapper, TrainableModelWrapper
 from NLP_LIB.nlp_core.dataset_wrapper import DatasetWrapper
-from keras.models import Model
-from keras.optimizers import Adam
-from keras.callbacks import TensorBoard, ModelCheckpoint, K
-from keras.utils import multi_gpu_model
+from NLP_LIB.optimizer.bert_optimizer import BERTOptimizer
+from tensorflow.keras.models import Model
+from tensorflow.keras.optimizers import Adam
+from tensorflow.keras.callbacks import TensorBoard, ModelCheckpoint
+from tensorflow.keras import backend as K
+from tensorflow.keras.utils import multi_gpu_model
 from tensorflow.python.client import device_lib
 from NLP_LIB.nlp_core.log_current_epoch_wrapper import LogCurrentEpochWrapper
 import tensorflow as tf
@@ -176,6 +178,18 @@ class TrainingWrapper:
     if optimizer == 'adam':
       optimizer_params = self.training_config['optimizer_params']
       optimizer = Adam(optimizer_params[0], optimizer_params[1], optimizer_params[2], epsilon=optimizer_params[3])
+    elif optimizer == 'bert_adam':
+      optimizer_params = self.training_config['optimizer_params'] 
+      # Calculate total step and set it to decay_steps (learning rate reachs 0 in the every end)
+      total_steps = batch_count * self.training_config['epochs']
+      print('[INFO] Training with BERT Optimizer with decay_steps = ' + str(total_steps))
+      optimizer = BERTOptimizer(
+        decay_steps = total_steps, # 100000,
+        warmup_steps = optimizer_params[2], # 10000,
+        learning_rate = optimizer_params[0], # 1e-4,
+        weight_decay = optimizer_params[1], # 0.01,
+        weight_decay_pattern=['embeddings', 'kernel', 'W1', 'W2', 'Wk', 'Wq', 'Wv', 'Wo'],                
+      )
     
     # Add model metric names and tensors to tracking list
     metric_names = self.trainable_model.get_metric_names()
